# GAD Common Utils

This package supply utility methods to create Airflow DAG setup under Aiola GAD Framework
[see](common_utils/gad_utils.py)

The package page in [PYPI](https://pypi.org/project/gad-common-utils/)
